import { NodeOrString, ElementOrString } from "./interfaces";

interface Dom {
    /**
     * Returns DOM node with matching `id` attribute or falsy value (ex: null or undefined)
     * if not found. Internally if `id` is not a string then `id` returned.
     */
    byId<E extends Element>(id: string | E, doc?: Document): E;

    /**
     * Returns true if node is a descendant of ancestor
     */
    isDescendant(node: NodeOrString, ancestor: NodeOrString): boolean;

    /**
     * Enable or disable selection on a node
     */
    setSelectable(node: ElementOrString, selectable?: boolean): void;
}

declare const dom: Dom;
export = dom;
